@@ -1,8 +1,8 @@
 package Job::Machine;
-$Job::Machine::VERSION = '0.19';
-1;
+$Job::Machine::VERSION = '0.22';
+use strict;
 
-__END__
+1;
 
 =pod
 
@@ -10,26 +10,14 @@ __END__
 
 =head1 NAME
 
-Job::Machine
+Job::Machine - Job queue handling using PostgreSQL.
 
 =head1 VERSION
 
-version 0.19
+version 0.22
 
 =head1 SYNOPSIS
 
-The Database:
-
-The Schema of Job::Machine is in sql/create_tables.sql. Just install it into your
-database. It is environmental friendly (will not pollute your namespace). By default
-it installs in a new jobmachine schema (PostgreSQL schema, not e,g, DBIC schema).
-
-=head2 NB!
-
-Starting wirh version 0.18, Job::Machine needs at least PostgreSQL 9.0.
-
-Using pg_notify means we need PostgreSQL >= 9.0
-
 =head2 The Client
 
   my $client = Job::Machine::Client->new(queue => 'job.task');
@@ -57,14 +45,14 @@ Back at the Client:
       print $client->receive->{baz};
   }
 
-=head1 DESCRIPTION
+=head2 Moose
 
-A small, but versatile system for sending jobs to a message queue and, if necessary,
-communicating answers back to the sender.
+Job::Machine doesn't use Moose itself, so this is the way to subclass it in a Moose environment:
 
-Job::Machine uses LISTEN / NOTIFY from PostgreSQL to send signals between
-clients and workers. This ensures very efficient message passing, giving any
-worker that is awake the chance to start working immediately.
+  use MooseX::NonMoose;
+  extends 'Job::Machine::Worker';
+
+This makes sure that Moose doesn't step on the precious new method.
 
 =head2 Database Connection
 
@@ -112,9 +100,32 @@ have it when the worker starts:
 
 You can access $self->{config} e.g. in your worker's startup and process methods.
 
+=head1 DESCRIPTION
+
+Job queue handling using PostgreSQL.
+
+A small, but versatile system for sending jobs to a message queue and, if necessary,
+communicating answers back to the sender.
+
+Job::Machine uses LISTEN / NOTIFY from PostgreSQL to send signals between
+clients and workers. This ensures very efficient message passing, giving any
+worker that is awake the chance to start working immediately.
+
+The Database:
+
+The Database Schema of Job::Machine is in sql/create_tables.sql. Just install it into your
+database. It is environmental friendly (will not pollute your namespace). By default
+it installs in a new jobmachine schema (Database schema, NOT DBIC schema; Job::Machine doesn't use DBIx::Class).
+
+=head2 NB!
+
+Starting with version 0.18, Job::Machine needs at least PostgreSQL 9.0.
+
+Using pg_notify means we need PostgreSQL >= 9.0
+
 =head1 NAME
 
-Job::Machine - Job queue handling
+Job::Machine
 
 =head1 SUPPORT
 
@@ -126,7 +137,7 @@ Kaare Rasmussen <kaare@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009,2014, Kaare Rasmussen
+Copyright (C) 2009,2015, Kaare Rasmussen
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
@@ -137,9 +148,15 @@ Kaare Rasmussen <kaare at cpan dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kaare Rasmussen.
+This software is copyright (c) 2015 by Kaare Rasmussen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+
+# PODNAME: Job::Machine
+# ABSTRACT: Job queue handling using PostgreSQL.
