@@ -1,5 +1,5 @@
 package Job::Machine::DB;
-$Job::Machine::DB::VERSION = '0.21';
+$Job::Machine::DB::VERSION = '0.22';
 use strict;
 use warnings;
 use Carp qw/croak confess/;
@@ -189,7 +189,7 @@ sub fetch_result {
 	};
 	my $result = $self->select_first(sql => $sql,data => [$id]) || return;
 
-	return $self->serializer->deserialize($result->{result})->{data};
+	return $self->serializer->deserialize($result->{result});
 }
 
 sub fetch_results {
@@ -375,7 +375,7 @@ Job::Machine::DB
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 NAME
 
